/*
*************************************************************
                                                                 
       Estimation Code of MDCEV with Triple Constraints    
                          v1.10

                        Written by 

                      Koich Kuriyama

            Division of Natural Resource Economics,
                Graduate School of Agriculture,
                      Kyoto University
                  Oiwake-cho, Kitashirakawa, 
                Sakyo-ku, Kyoto 606-8502, JAPAN
                 E-mail kkuri@kais.kyoto-u.ac.jp
      Web: http://kkuri.eco.coocan.jp/index-e.html

                         05/03/2017

*************************************************************
*/

new , 40000;
outwidth 256;
screen on;
cls;

@--------------------------@
@      SETTING START       @
@--------------------------@

@ Output File Setting @
output file = MDCEV_TC.out reset;

@ Loading data @
load DATA[100,25] = data.txt; @ Data File @

@ Number of observations @
N_OBS = rows(DATA);

@ Number of inside goods (excluding the outside goods) @
N_INSIDE = 3;

@ CHOICE SET of inside goods (1: include, 0: not include) @
CSET_INSIDE = ones(N_OBS,N_INSIDE);

@ Nubmer of Psi variables for inside goods @
N_PSI = 3; 

@ Number of constraints @
N_CONSTRAINTS = 3;    @ 1: budget, 2: budget + time, 3: budget + time1 + time2 @


@--------------------------@
@ PREFERENCE SPECIFICATION @
@--------------------------@

@ Alpha: 4 x 1, if ALPHAKFIX = 0. (3 + N_INSIDE) x 1, if ALPHAKFIX = 1. @
@  1: estimate, 0: not estimate (alpha = 0), -1: estimated alphas are constrained to be equal to alphak @
ALPHA_EST = {
	1, @ alhpa1 (money) @
 	0, @ alpha2 (time1: weekend) @
	0, @ alpha3 (time2: long holiday) @
	0  @ alphak of inside goods @
}; 

@ gamma: 1 x 1, if GAMMAKFIX = 0. N_INSIDE x 1, if GAMMAKFIX = 1. @
@  1: estimate, 0: not estimate (gammak = 1) @
GAMMA_EST = {
	1  @ gammak of inside goods @
};     @ gamma1, gamma2, and gamma3 are always fixed at 0 @

@ Sigma: 4 x 1, if SIGKFIX = 0. (3 + N_INSIDE) x 1, if SIGKFIX = 1. @
@  1: estimate, 0: not estimate (sig = 0), -1: estimated sigmas are constrained to be equal to sigk @
SIG_EST = {
	1, @ sig1 @
	1, @ sig2 @
	1  @ sig3 @
};     @ sigk of inside goods is always estimated @

@ XI ESTIMATION (3 x 1) @
@  1: estimate, 0: not estimate (use 0) @
XI_EST = {
	0, @ xi1: money @
	0, @ xi2: time of the weekend @
	0  @ xi3: time of the long holiday @
}; 

@ OTHER SETTING OF PARAMETERS @
@ 1: good specific fixed effect, 0: equal to all indside goods @
ALPHAKFIX = 0; @ 1: alphak is fixed effect, 0: otherwise @
GAMMAKFIX = 0; @ 1: gammak is fixed effect, 0: otherwise @
SIGKFIX = 0;   @ 1: sigk is fixed effect, 0: otherwise @

@--------------------------@
@     STARTING VALUES      @
@--------------------------@

@ Psi: N_PSI x 1 @
B_PSI = {
   -1.0 , @ Psi1: const. @
    0.0 , @ Psi2: individual attribute 1 @
    0.0   @ Psi3: individual attribute 2 @
};

@ Xi: 3 x 1 @
B_XI ={
    0.0 , @ xi1:  x1 (money) @
    0.0 , @ xiS:  x2 (weekend) @
    0.0   @ xiL:  x3 (long holiday) @
};

@ Alpha: 4 x 1, if ALPHAKFIX = 0. (3 + N_INSIDE) x 1, if ALPHAKFIX = 1. @
B_ALPHA = {
   -1.0 , @ alpha1:  x1 @  
    0.0 , @ alpha2:  x2 @
    0.0 , @ alpha3:  x3 @
    0.0  @ alphak:  xk (1 x 1, if ALPHAKFIX = 0. N_INSIDE x 1, if ALPHAKFIX = 1) @
};

@ gammak: 1 x 1, if GAMMAKFIX = 0. N_INSIDE x 1, if GAMMAKFIX = 1. @
B_GAMMA = {
    1   @ gammak:  xk (1 x 1, if GAMMAKFIX = 0. N_INSIDE x 1, if GAMMAKFIX = 1.) @
};

@ Sigma: 4 x 1, if SIGKFIX = 0. (3 + N_INSIDE) x 1, if SIGKFIX = 1. @
B_SIGMA = {
   -0.1 , @ sigma1:  x1 @
    0.0 , @ sigma2:  x2 @
    0.0 , @ sigma3:  x3 @
   -0.4   @ sigmak:  xk (1 x 1, if SIGKFIX = 0. N_INSIDE x 1, if SIGKFIX = 1.) @
};

@--------------------------@
@       OTHER SETTING      @
@--------------------------@

@ Number of iteration of simulated likelihood @
N_SIM = 200;

@ HALT = 1 if Halton sequences, 0 otherwise @
HALT = 1;

@ Random seed @
SEED1 = 12345;

@ Maximum number of iterations in the maximum likelihood estimation @
ML_NITER = 1000;

@ Tolerance for convergence @
ML_TOL = 1.e-5;

@ Optimization algorithm @
@ MAXLIK   1:STEEP, 2:BFGS, 3:DFP, 4:Newton, 5:BHHH, 6:PRCG @
@ MAXLIKMT 1:BFGS, 2:DFP, 3:Newton, 4:BHHH @
ML_ALG = 2; 

@--------------------------@
@        SETTING END       @
@--------------------------@

@ Generating data @
/*
Data format for N_INSIDE = 3
  1:    person id 
  2- 4: consumption of inside goods in weekends
  5- 7: consumption of inside goods in long holiday
  8- 10: psi1 (const.)
 11- 13: psi2
 14- 16: psi3
 17:     income
 18- 20: price
 21:     Max_TS
 22:     Max_TL
 23- 25: time
*/
IDX = 2;
XINSIDE_S = DATA[.,IDX:(IDX+N_INSIDE-1)]; @ X_Inside_S @
IDX = IDX + N_INSIDE;
XINSIDE_L = DATA[.,IDX:(IDX+N_INSIDE-1)]; @ X_Inside_L @
IDX = IDX + N_INSIDE;
PSIDATA = DATA[.,IDX:(IDX+N_INSIDE.*N_PSI-1)]; @ Psi @
IDX = IDX + N_INSIDE.*N_PSI;
INCOME = DATA[.,IDX];  @ Income @
IDX = IDX + 1;
PRICE = DATA[.,IDX:(IDX+N_INSIDE-1)]; @ Price @
IDX = IDX + N_INSIDE;
MAX_TS = DATA[.,IDX]; @ Max_Time of x2 (weekend) @
IDX = IDX + 1;
MAX_TL = DATA[.,IDX]; @ Max_Time of x3 (long holiday) @
IDX = IDX + 1;
TTIME = DATA[.,IDX:(IDX+N_INSIDE-1)]; @ two-way trip time @

N_INSIDE_ORG = N_INSIDE;
PSIDATA_ORG = PSIDATA;
if N_CONSTRAINTS .== 3;
     tmp = zeros(N_OBS,1);
     k = 1;
     do while k .le N_PSI;
         idx = (k-1).*N_INSIDE+1;
         idx2 = idx + N_INSIDE - 1;
         tmp = tmp~PSIDATA[.,idx:idx2]~PSIDATA[.,idx:idx2];
         k = k + 1;
    endo;
    PSIDATA = tmp[.,2:cols(tmp)];
    XINSIDE = XINSIDE_S~XINSIDE_L;
    PRICE = PRICE~PRICE;
    TTIME = TTIME~TTIME;
    CSET_INSIDE = CSET_INSIDE~CSET_INSIDE;
    SK = ones(N_OBS,N_INSIDE)~zeros(N_OBS,N_INSIDE);
    SK2 = 1 - SK;
    N_INSIDE = N_INSIDE*2;
else;
    XINSIDE = XINSIDE_S + XINSIDE_L;
    SK = ones(N_OBS,N_INSIDE);
    SK2 = zeros(N_OBS,N_INSIDE);
endif;    
XOUT1 = INCOME - sumc((PRICE.*XINSIDE)'); @ Hicks composite good of money @

@ Starting value @
DUM_STOP = 0;
if rows(B_PSI) ./= N_PSI;
    print "Error in B_PSI";
    DUM_STOP = DUM_STOP + 1;
endif;
if rows(B_XI) ./= 3;
    print "Error in B_PSI";
    DUM_STOP = DUM_STOP + 1;
endif;
if ALPHAKFIX .== 1;
    if rows(B_ALPHA) ./= (3 + N_INSIDE_ORG);
        print "Error in B_ALPHA";
        DUM_STOP = DUM_STOP + 1;
    endif;
elseif rows(B_ALPHA) ./= 4;   
    print "Error in B_ALPHA";
    DUM_STOP = DUM_STOP + 1;
endif;
if GAMMAKFIX .== 1;
    if rows(B_GAMMA) ./= N_INSIDE_ORG;
        print "Error in B_GAMMA";
        DUM_STOP = DUM_STOP + 1;
    endif;
elseif rows(B_GAMMA) ./= 1;   
    print "Error in B_GAMMA";
    DUM_STOP = DUM_STOP + 1;
endif;     
if SIGKFIX .== 1;
    if rows(B_SIGMA) ./= (3 + N_INSIDE);
        print "Error in B_SIGMA";
        DUM_STOP = DUM_STOP + 1;
    endif;
elseif rows(B_SIGMA) ./= 4;   
    print "Error in B_SIGMA";
    DUM_STOP = DUM_STOP + 1;
endif;      
if DUM_STOP > 0;
    stop;
endif;
      
B = B_PSI|B_XI|B_ALPHA|B_GAMMA|B_SIGMA;
  
@ BACTIVE = 1 if estimated, 0 if fixed @
BACTIVE = ones(rows(b),1);
IDX1 = rows(B_PSI) + 1;
IDX2 = IDX1 + rows(XI_EST) - 1;
if N_CONSTRAINTS == 1;
    XI_DUMMY = {1,0,0};
    SC_MODEL = 1;
    DC_MODEL = 0;
    TC_MODEL = 0;
elseif N_CONSTRAINTS == 2;
    XI_DUMMY = {1,1,0};
    SC_MODEL = 0;
    DC_MODEL = 1;
    TC_MODEL = 0;
elseif N_CONSTRAINTS == 3;
    XI_DUMMY = {1,1,1};
    SC_MODEL = 0;
    DC_MODEL = 0;
    TC_MODEL = 1;
endif;    
BACTIVE[IDX1:IDX2] = (XI_EST.==1).*XI_DUMMY;  
B[IDX1:IDX2] = B[IDX1:IDX2].*(XI_EST.==1).*XI_DUMMY;
IDX1 = IDX2 + 1;
IDX2 = IDX1 + rows(B_ALPHA) - 1;
BACTIVE[IDX1:IDX2] = (ALPHA_EST.==1);  
BACTIVE[IDX1:(IDX1+2)] = BACTIVE[IDX1:(IDX1+2)].*XI_DUMMY;  
B[IDX1:IDX2] = B[IDX1:IDX2].*(ALPHA_EST.==1);  
B[IDX1:(IDX1+2)] = B[IDX1:(IDX1+2)].*XI_DUMMY; 
IDX1 = IDX2 + 1;
IDX2 = IDX1 + rows(GAMMA_EST) - 1;
BACTIVE[IDX1:IDX2] = (GAMMA_EST.==1);
B[IDX1:IDX2] = B[IDX1:IDX2].*(GAMMA_EST.==1) + (GAMMA_EST./=1);  
IDX1 = IDX2 + 1;
IDX2 = IDX1 + rows(B_SIGMA) - 1;
BACTIVE[IDX1:(IDX1+2)] = (SIG_EST.==1);
BACTIVE[IDX1:(IDX1+2)] = BACTIVE[IDX1:(IDX1+2)].*XI_DUMMY;  
B[IDX1:(IDX1+2)] = B[IDX1:(IDX1+2)].*(SIG_EST.==1);
B[IDX1:(IDX1+2)] = B[IDX1:(IDX1+2)].*XI_DUMMY; 

@ Variable names @
V_PSI = 0 $+ "PSI" $+ ftocv(seqa(1,1,rows(B_PSI)),2,0);
V_XI = {"Xi1", "XiS", "XiL"};
V_ALPHAOUT = {"AlpOut01", "AlpOut02", "AlpOut03"};
V_ALPHAIN = 0 $+ "AlpIn" $+ ftocv(seqa(1,1,rows(B_ALPHA)-3),2,0);
V_GAMMA = 0 $+ "GamIn" $+ ftocv(seqa(1,1,rows(B_GAMMA)),2,0);
V_SIGOUT = {"SigOut01", "SigOut02", "SigOut03"};
V_SIGIN = 0 $+ "SigIn" $+ ftocv(seqa(1,1,rows(B_SIGMA)-3),2,0);
VNAME = V_PSI|V_XI|V_ALPHAOUT|V_ALPHAIN|V_GAMMA|V_SIGOUT|V_SIGIN;
@ Generating random numbers @

prim = { 3 5 7 11 13 17 19 23 29 31 37 41 43 47 53 59 61 67 71
         73 79 83 89 97 101 103 107 109 113 };

SIMS = zeros(N_OBS,1);
N_RANDOM = 3; @ ontside goods: x1, x2, x3 @

i = 1;
if HALT == 1 and N_SIM > 1;
    do while i <= N_RANDOM;
        halt1 = halton(10+N_OBS*N_SIM,prim[i]);
        SIMS = SIMS~halt1;
        i = i + 1;
    endo;
    SIMS = SIMS[.,2:(N_RANDOM*N_SIM+1)];
elseif HALT == 0 and N_SIM > 1;
    SIMS = -ln(-ln(-rndus(N_OBS,(N_RANDOM*N_SIM),SEED1))); @ Type I extreme value @
endif;
print "Starting values:";
print B;

library maxlik,pgraph;
#include maxlik.ext;
maxset;
_max_GradTol = ML_TOL;
_max_MaxIters = ML_NITER;
_max_Algorithm = ML_ALG;
_max_CovPar = 1; @ 1: Hessian, 2: cross-product of Jacobian, 3: QML @
_max_Active = BACTIVE;
_max_ParNames = VNAME;
if N_CONSTRAINTS == 3;
    __title = "MDCEV with Triple Constraints Model";
elseif N_CONSTRAINTS == 2;
    __title = "MDCEV with Double Constraints Model";
elseif N_CONSTRAINTS == 1;
    __title = "MDCEV with Single Constraint Model";
endif;    
    
{beta,f,g,cov,ret} = maxlik(PSIDATA,0,&ll,B);
call maxprt(beta,f,g,cov,ret);
format /m1 /res 16,6;
print;
print "beta";
print beta;
print;
print "cov";
print cov;
print;
format /mb1 /ros 16,8;



@ PROCEDURE FOR GENERATING HALTON SEQUENCES FOR TYPE I EXTREME VALUE @

proc halton(n,s);
    local phi,phif,i,j,y,x,k;
    k = floor(ln(n+1) ./ ln(s));
    phi = {0};
    i = 1;
    do while i .le k;
        x = phi;
        j = 1;
        do while j .lt s;
            y = phi + (j/s^i);
            x = x|y;
            j = j + 1;
        endo;
        phi = x;
        i = i + 1;
    endo;
    x = phi;
    j = 1;
    do while j .lt s .and rows(x) .lt (n+1);
        y = phi + (j/s^i);
        x = x|y;
        j = j + 1;
    endo;
    phi=-ln(-ln(x[11:(n+1),1])); @ Type I extreme value @
    phif = reshape((phi)',N_OBS,N_SIM);
    retp(phif);
endp;


@ LOG-LIKELIHOOD FUNCTION 						@

proc ll(bn,x);
    local sigk, ppsi;  
    local s, k, k2, c1, det1, det2, gumbelk, gammak, psik;
    local like, like1, likelogit;
    local xi1, xis, xil;
    local pjpkn, tjtkn, sjskn, sjskn2;
    local x2i, x3i;
    local eps1, eps2, eps3;
    local sig1, sig2, sig3; 
    local alpha1, alpha2, alpha3, alphak; 

    @ Loading parameters @
    k = 1;
    @ PSI @
    if N_PSI > 0;
        ppsi = bn[k:(k+N_PSI-1)];
        k = k + N_PSI;
    else;
        ppsi  = 0;
    endif;

    @ XI @
    xi1 = (XI_EST[1] != 1).* 0 + (XI_EST[1] ==1) .* (bn[k]);  
    k = k + 1;
    xis = (XI_EST[2] != 1).* 0 + (XI_EST[2] ==1) .* (bn[k]);  
    k = k + 1;
    xil = (XI_EST[3] != 1).* 0 + (XI_EST[3] ==1) .* (bn[k]);  
    k = k + 1;  

    @ ALPHA @
    alpha1 = 1-exp(bn[k]);  
    k = k + 1;
    alpha2 = 1-exp(bn[k]);  
    k = k + 1;
    alpha3 = 1-exp(bn[k]);  
    k = k + 1;
    if ALPHAKFIX == 1;
        alphak = (1-exp(bn[k:(k+N_INSIDE_ORG-1)]))'; 
		alphak = alphak~alphak;
        k = k + N_INSIDE_ORG;
    else;
        alphak = 1-exp(bn[k]);
        k = k + 1;
    endif;
  
    alpha1 = (alpha_EST[1] == 0).* 0 + (alpha_EST[1] == -1).* alphak[1] + (alpha_EST[1] ==1) .* alpha1;
    alpha2 = (alpha_EST[2] == 0).* 0 + (alpha_EST[2] == -1).* alphak[1] + (alpha_EST[2] ==1) .* alpha2;
    alpha3 = (alpha_EST[3] == 0).* 0 + (alpha_EST[3] == -1).* alphak[1] + (alpha_EST[3] ==1) .* alpha3;
    alphak = (alpha_EST[4] == 0).* 0 + (alpha_EST[4] ==1) .* alphak;

    @ gamma @
    if GAMMAKFIX == 1;
		gammak = exp(bn[k:(k+N_INSIDE_ORG-1)])';
		gammak = (gammak~gammak).*ones(N_OBS,N_INSIDE);
        gammak = ((gamma_EST|gamma_EST)' ./= 1).* ones(N_OBS,N_INSIDE)
		       + ((gamma_EST|gamma_EST)' .==1) .* gammak;
        k = k + N_INSIDE_ORG;
    else;
        gammak = exp(bn[k]).*ones(N_OBS,N_INSIDE);
        k = k + 1;
        gammak = (gamma_EST[1] /= 1).* ones(N_OBS,N_INSIDE) + (gamma_EST[1] ==1) .* gammak;
    endif;
    
    @ SIGMA @
    sig1 = exp(bn[k]);
    sig2 = exp(bn[k+1]);
    sig3 = exp(bn[k+2]);
    k = k + 3;

    if SIGKFIX /= 1;
        sigk = exp(bn[k].*ones(1,N_INSIDE));
        k = k + 1;
    else;
        sigk = exp(bn[k:(k+N_INSIDE-1)]');
        k = k + N_INSIDE;
    endif;  
  
    sig1 = (sig_EST[1] == -1).* sigk[.,1] + (sig_EST[1] == 0).* 0 + (sig_EST[1] ==1) .* sig1;
    sig2 = (sig_EST[2] == -1).* sigk[.,1] + (sig_EST[2] == 0).* 0 + (sig_EST[2] ==1) .* sig2;
    sig3 = (sig_EST[3] == -1).* sigk[.,1] + (sig_EST[3] == 0).* 0 + (sig_EST[3] ==1) .* sig3;

    x2i = Max_TS - sumc((TTIME.*sk.*XINSIDE)'); @ x2i: outside demand of a weekend  @
    x3i = Max_TL - sumc((TTIME.*(1-sk).*XINSIDE)'); @ x3i: outside demand of a long holiday  @
    like = zeros(N_OBS,1);
    s = 1;
    do while s <= N_SIM;       
        c1 = 0;  
        eps1 = SIMS[1:N_OBS,s].*sig1;
        eps2 = SIMS[1:N_OBS,(s+N_SIM)].*sig2;
        eps3 = SIMS[1:N_OBS,(s+N_SIM*2)].*sig3;
        det1 = zeros(N_OBS,1);
        k = 1;
        do while k <= N_OBS;  
          if sumc((XINSIDE[k,.].*CSET_INSIDE[k,.])') .eq 0;
            det1[k] = 1;
          else;        
            det2 = ( ( ((1-alpha1).*(PRICE[k,.]')*PRICE[k,.].*XOUT1[k]^(alpha1-2).*exp(xi1+eps1[k])
                 + (1-alpha2).*((TTIME[k,.]')*TTIME[k,.]).* XI_DUMMY[2].* exp(xis+eps2[k]).* x2i[k]^(alpha2-2).*((sk[k,.]')*sk[k,.])
                 + (1-alpha3).*((TTIME[k,.]')*TTIME[k,.]).* XI_DUMMY[3].* exp(xil+eps3[k]).* x3i[k]^(alpha3-2).*((sk2[k,.]')*sk2[k,.])
                 ) ./          
                 (PRICE[k,.].*XOUT1[k]^(alpha1-1).*exp(xi1+eps1[k])
                 + XI_DUMMY[2].* exp(xis+eps2[k]).*TTIME[k,.].* sk[k,.].*x2i[k]^(alpha2-1) 
                 + XI_DUMMY[3].* exp(xil+eps3[k]).*TTIME[k,.].* sk2[k,.].*x3i[k]^(alpha3-1))
               .*ones(N_INSIDE,N_INSIDE)+ 
               (eye(N_INSIDE).*((1-alphak)./(XINSIDE[k,.] + 
               gammak[k,.]))) ).*(XINSIDE[k,.] ./= 0) ).*
               ( (XINSIDE[k,.].*CSET_INSIDE[k,.] ./=0) )';
            det2 = (XINSIDE[k,.].*CSET_INSIDE[k,.] .== 0).*eye(N_INSIDE) + det2;          
            det1[k] = abs(det(det2));
          endif;
          k = k + 1;
        endo;        
        psik = zeros(N_OBS, N_INSIDE);
        k = 1 ;
        do while k <= N_PSI;
            psik = psik + ( ppsi[k].*ones(N_OBS,1) )
               .* PSIDATA[.,((k-1)*N_INSIDE+1):(k*N_INSIDE)];
            k = k + 1;
        endo; 

        gumbelk = ( -psik + ln(PRICE.*XOUT1^(alpha1-1).*exp(xi1+eps1) 
	        + XI_DUMMY[2].* exp(xis+eps2).*TTIME.*sk.*x2i^(alpha2-1)
			+ XI_DUMMY[3].* exp(xil+eps3).*TTIME.*(1-sk).*x3i^(alpha3-1))
            + (1-alphak).*my_ln(XINSIDE ./ gammak + 1) )./sigk;

        like1 = (XINSIDE./=0).*( -gumbelk - my_ln(sigk).*
            ones(N_OBS,N_INSIDE) ) + -exp(-gumbelk);
        like = like + det1.*my_exp( sumc((CSET_INSIDE.*like1)') )./ N_SIM;
        s = s + 1; 							       
    endo;
    like = my_ln(like);
    
    retp(like);						 
endp;

@ My Procedure for Generating ln(x) @

proc my_ln(x);
   local y;
   y = (x.<1e-250).*1e-250 + (x.>=1e-250).*x;
   retp(ln(y));
endp;


@ My Procedure for Generating exp(x) @

proc my_exp(x);
   local y;
   y = (x.<-700).*(-700)+(abs(x).<=700).*x+(x.>=700).*(700);
   retp(exp(y));
endp;

/*
N_SIM:200
alpha-gamma profile
===============================================================================
                      MDCEV with Triple Constraints Model                      
===============================================================================
 MAXLIK Version 5.0.2                                      5/09/2017  11:35 am
===============================================================================

return code =    0
normal convergence

Mean log-likelihood        -2.69573
Number of cases     100

Covariance matrix of the parameters computed by the following method:
Inverse of computed Hessian

Parameters    Estimates     Std. err.  Est./s.e.  Prob.    Gradient
------------------------------------------------------------------
PSI01           -2.9766        0.4282   -6.951   0.0000      0.0000
PSI02            0.9111        0.0320   28.462   0.0000      0.0000
PSI03           -1.1184        0.0395  -28.288   0.0000      0.0000
Xi1              0.0000             .        .        .      0.0000
XiS              0.0000             .        .        .      0.0000
XiL              0.0000             .        .        .      0.0000
AlpOut01        -0.5617        0.0616   -9.113   0.0000      0.0000
AlpOut02         0.0000             .        .        .      0.0000
AlpOut03         0.0000             .        .        .      0.0000
AlpIn01          0.0000             .        .        .      0.0000
GamIn01          0.7782        0.0920    8.463   0.0000      0.0000
SigOut01         0.9832        0.0370   26.541   0.0000      0.0000
SigOut02        -0.0639        0.0605   -1.056   0.2909      0.0000
SigOut03       -11.6398      586.7464   -0.020   0.9842      0.0000
SigIn01         -1.8950        0.0963  -19.686   0.0000      0.0000

Correlation matrix of the parameters
   1.000  -0.597   0.544       .       .       .  -0.926       .       .       .  -0.120  -0.614   0.808  -0.002   0.093
  -0.597   1.000  -0.874       .       .       .   0.337       .       .       .  -0.265   0.870  -0.209   0.002   0.112
   0.544  -0.874   1.000       .       .       .  -0.391       .       .       .   0.191  -0.899   0.246  -0.003  -0.072
       .       .       .       .       .       .       .       .       .       .       .       .       .       .       .
       .       .       .       .       .       .       .       .       .       .       .       .       .       .       .
       .       .       .       .       .       .       .       .       .       .       .       .       .       .       .
  -0.926   0.337  -0.391       .       .       .   1.000       .       .       .   0.056   0.425  -0.878   0.001  -0.114
       .       .       .       .       .       .       .       .       .       .       .       .       .       .       .
       .       .       .       .       .       .       .       .       .       .       .       .       .       .       .
       .       .       .       .       .       .       .       .       .       .       .       .       .       .       .
  -0.120  -0.265   0.191       .       .       .   0.056       .       .       .   1.000  -0.126  -0.075   0.002  -0.196
  -0.614   0.870  -0.899       .       .       .   0.425       .       .       .  -0.126   1.000  -0.308   0.002   0.048
   0.808  -0.209   0.246       .       .       .  -0.878       .       .       .  -0.075  -0.308   1.000  -0.001   0.120
  -0.002   0.002  -0.003       .       .       .   0.001       .       .       .   0.002   0.002  -0.001   1.000   0.000
   0.093   0.112  -0.072       .       .       .  -0.114       .       .       .  -0.196   0.048   0.120   0.000   1.000

Number of iterations    68
Minutes to convergence     0.95033

beta

  -2.976624e+000 
   9.110636e-001 
  -1.118436e+000 
   1.000000e-012 
   1.000000e-012 
   1.000000e-012 
  -5.617168e-001 
   1.000000e-012 
   1.000000e-012 
   1.000000e-012 
   7.782308e-001 
   9.832085e-001 
  -6.391609e-002 
  -1.163984e+001 
  -1.895002e+000 

cov

   1.833782e-001   -8.180082e-003    9.206110e-003                .                .                .   -2.444778e-002                .                .                .   -4.708512e-003   -9.746209e-003    2.093262e-002   -4.715471e-001    3.817942e-003 
  -8.180082e-003    1.024663e-003   -1.105776e-003                .                .                .    6.649527e-004                .                .                .   -7.786635e-004    1.031688e-003   -4.050416e-004    3.864205e-002    3.437264e-004 
   9.206110e-003   -1.105776e-003    1.563167e-003                .                .                .   -9.539872e-004                .                .                .    6.944784e-004   -1.316993e-003    5.877193e-004   -5.878506e-002   -2.732562e-004 
               .                .                .                .                .                .                .                .                .                .                .                .                .                .                . 
               .                .                .                .                .                .                .                .                .                .                .                .                .                .                . 
               .                .                .                .                .                .                .                .                .                .                .                .                .                .                . 
  -2.444778e-002    6.649527e-004   -9.539872e-004                .                .                .    3.799262e-003                .                .                .    3.166655e-004    9.705252e-004   -3.274709e-003    4.445380e-002   -6.742595e-004 
               .                .                .                .                .                .                .                .                .                .                .                .                .                .                . 
               .                .                .                .                .                .                .                .                .                .                .                .                .                .                . 
               .                .                .                .                .                .                .                .                .                .                .                .                .                .                . 
  -4.708512e-003   -7.786635e-004    6.944784e-004                .                .                .    3.166655e-004                .                .                .    8.456123e-003   -4.281476e-004   -4.152479e-004    9.190008e-002   -1.734067e-003 
  -9.746209e-003    1.031688e-003   -1.316993e-003                .                .                .    9.705252e-004                .                .                .   -4.281476e-004    1.372375e-003   -6.897862e-004    4.715856e-002    1.723513e-004 
   2.093262e-002   -4.050416e-004    5.877193e-004                .                .                .   -3.274709e-003                .                .                .   -4.152479e-004   -6.897862e-004    3.661684e-003   -2.930819e-002    6.961080e-004 
  -4.715471e-001    3.864205e-002   -5.878506e-002                .                .                .    4.445380e-002                .                .                .    9.190008e-002    4.715856e-002   -2.930819e-002    3.442714e+005   -2.713346e-002 
   3.817942e-003    3.437264e-004   -2.732562e-004                .                .                .   -6.742595e-004                .                .                .   -1.734067e-003    1.723513e-004    6.961080e-004   -2.713346e-002    9.266535e-003 


*/
